@@ -3121,9 +3121,21 @@ def save():
 	with open('word_awl.json','w') as fw: 
 		fw.write(json.dumps([ w for w in word_awl]))
 
-def save_tsv():
+def tsv():
 	with open('awl.tsv','w') as fw: 
 		[ fw.write(f"{w}\n") for w in word_awl]
 
+def tomysql(db, host='172.18.0.1', port=3307):
+	''' db: kpsi  '''
+	import pymysql
+	my_conn = pymysql.connect(host=host,port=port,user='root',password='cikuutest!',db=db)
+	with my_conn.cursor() as cursor: 
+		cursor.execute(f"drop TABLE if exists word_awl")
+		cursor.execute(f"CREATE TABLE if not exists word_awl(word varchar(64) COLLATE latin1_bin not null primary key) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
+		cursor.executemany(f"insert ignore into word_awl(word) values(%s)",[(k,) for k in word_awl])
+		my_conn.commit()
+	print ("finished submitting:", db, flush=True) 
+
 if __name__ == '__main__': 
-	save_tsv()
\ No newline at end of file
+	import fire
+	fire.Fire()
\ No newline at end of file
