@@ -64,7 +64,7 @@ def sntmkf(snt:str, gec:str, diffmerge:bool=False, dskhost:str="172.17.0.1:7095"
 		print(">>sntmkf Ex:", ex, "\t|", snt)
 
 def sntsmkf(pairs:list =[["She has ready.","She is ready."], ["It are ok.","It is ok.", 1]], 
-		dskhost:str="dsk.jukuu.com", asdsk:bool=False , diffmerge:bool=False, getdoc=lambda snt: spacy.nlp(snt)
+		dskhost:str="127.0.0.1:7095", asdsk:bool=False , diffmerge:bool=False, getdoc=lambda snt: spacy.nlp(snt)
 		):
 	''' snts -> mkfs,  if asdsk=True, return dsk , with info, kw, doc   '''
 	try:
