@@ -1,15 +1,16 @@
 # 22-6-4 
-import pika,json, sys, fire, time, dsk,requests
+import pika,json, sys, fire, time, dsk,requests, pipe
 		
 def consume(queue_name,  dst_exchange, routing_key='',  host='172.17.0.1', port=5672, user='root', pwd='', heartbeat=120, durable=True
-		, gechost='gpu120.wrask.com:8180', dskhost='172.17.0.1:7095'): 
-	''' 2022.6.4 '''
+		, gechost=None, dskhost='172.17.0.1:7095'): 
+	''' gpu120.wrask.com:8180 2022.6.4 '''
 	credentials = pika.PlainCredentials(user, pwd)  
 	connection	= pika.BlockingConnection(pika.ConnectionParameters(host = host,port = port,virtual_host = '/',credentials = credentials))
 	channel		= connection.channel()
 	result		= channel.queue_declare(queue = queue_name, durable=durable) 
-	gec_func	= lambda snts: requests.post(f"http://{gechost}/redis/getgecs", json=snts).json () 
-	print("queue is :", queue_name, flush=True)
+	gec_func	= pipe.gecsnts
+	if gechost: gec_func = lambda snts: requests.post(f"http://{gechost}/redis/getgecs", json=snts).json ()
+	print("queue is :", queue_name,  gec_func, flush=True)
 
 	def callback(ch, method, properties, body):
 		try:
