@@ -48,9 +48,8 @@ def mysql(dbfile, host='127.0.0.1', port=3307):
 		cursor.execute(f"drop TABLE if exists {name}_snt")
 		cursor.execute(f"CREATE TABLE if not exists {name}_snt(sid int primary key, snt text not null, kps text not null, fulltext key `snt`(`snt`), fulltext key `kps`(`kps`) ) engine=myisam  DEFAULT CHARSET=latin1 COLLATE=latin1_bin")
 
-		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+		for rowid, snt, doc in tqdm(Spacybs(dbfile).docs()) :
 			try:
-				doc =  spacy.frombs(bs)
 				cursor.execute(f"insert ignore into {name}_snt(sid, snt, kps) values(%s, %s, %s)", (rowid,snt, " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')]) ))
 				walk(doc)
 			except Exception as e: 
@@ -68,9 +67,8 @@ def tsv(dbfile):
 	name = dbfile.lower().split('.')[0]
 	fire.si = Counter()
 	with open (f"{name}.tsv.snt", "w", encoding='UTF-8') as fw:
-		for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
-			try:
-				doc =  spacy.frombs(bs)
+		for rowid, snt, doc in tqdm(Spacybs(dbfile).docs()) : #for rowid, snt, bs in tqdm(Spacybs(dbfile).items()) :
+			try: #doc =  spacy.frombs(bs)
 				terms = " ".join([ f"{t.lemma_}_{t.pos_}" for t in doc] + [ f"{t.lemma_}_{t.tag_}" for t in doc] + [ f"{t.head.lemma_}_{t.head.pos_}_{t.dep_}_{t.pos_}_{t.lemma_}" for t in doc if t.pos_ not in ('PRON','PUNCT') and t.dep_ in ('dobj','nsubj','advmod','acomp','amod','compound','xcomp','ccomp')]) 
 				fw.write(f"{rowid}\t{snt}\t{terms}\n")
 				walk(doc)
