@@ -28,8 +28,8 @@ class Spacybs(UserDict): # change to a neutral name, such as Dbdict ?  then Docb
 		for	value in self.conn.execute(f'SELECT value FROM {self.tablename} ORDER BY rowid  limit {start},{len}').fetchall(): yield value[0]
 	def	items(self, start=0, len=-1): 
 		for rowid, key, value in self.conn.execute(f'SELECT rowid, key, value FROM	{self.tablename} ORDER BY rowid limit {start},{len}' ).fetchall(): 	yield rowid, key, value
-	def	docs(self, start=0, len=-1): 
-		for	value in self.conn.execute(f'SELECT value FROM {self.tablename} ORDER BY rowid  limit {start},{len}').fetchall(): yield from_docbin(value[0])
+	def	docs(self, start=0, len=-1): # for rowid, snt, doc in spacybs.Spacybs(infile).docs() , added 2022.7.9
+		for rowid, key, value in self.conn.execute(f'SELECT rowid, key, value FROM	{self.tablename} ORDER BY rowid limit {start},{len}' ).fetchall(): 	yield rowid, key, en.from_docbin(value)
 
 	def	__contains__(self, key): return self.conn.execute('SELECT 1 FROM "%s" WHERE key = ?' %	self.tablename, (key,)).fetchone() is not None
 
