@@ -100,7 +100,7 @@ config = {
 			"sid": { "type": "keyword"},
 			"id": { "type": "keyword"},
 			"rid": { "type": "keyword"},
-			"did": { "type": "integer"},
+			"did": { "type": "keyword"},
 			"ibeg": { "type": "integer"},
 			"iend": { "type": "integer"},
 			"len": { "type": "integer"}, # [start, start + len) 
