@@ -86,6 +86,13 @@ class ES(object):
 		requests.esport	= esport
 		requests.es		= Elasticsearch([ f"http://{requests.eshost}:{requests.esport}" ])  
 
+	def list(self): 
+		''' list current index, show tables '''
+		[print(row) for row in rows("show tables")]
+	def sql(self, query): 
+		''' run the given query, ie: select count(*) from dic '''
+		[print(row) for row in rows(query)]
+
 	def addfolder(self, folder:str, pattern=".txt", idxname=None): 
 		''' folder -> docbase, 2022.1.23 '''
 		if idxname is None : idxname=  folder
